﻿using System;
using System.Reflection;

namespace Dsl.Ped.Common.Helpers
{
    /// <summary>
    /// Helper methods for <see cref="Assembly"/>
    /// </summary>
    public class AssemblyHelper
    {
        /// <summary>
        /// Get the version string of assembly in a format 'Version: [long_number]'
        /// </summary>
        /// <param name="assembly">
        /// The assembly.
        /// </param>
        /// <returns>Long version string </returns>
        public static string GetLongVersionString(Assembly assembly)
        {
            return assembly == null ?
                string.Empty :
                string.Format("{0} {1}", "Version", GetLongVersion(assembly));
        }

        /// <summary>
        /// Get the version string of assembly in a format 'Version: [short_number]'
        /// </summary>
        /// <param name="assembly">The assembly</param>
        /// <param name="length">The length of the version string</param>
        /// <returns>Short version string</returns>
        public static string GetShortVersionString(Assembly assembly, int length = 2)
        {
            return assembly == null ?
                string.Empty :
                string.Format("{0} {1}", "Version", GetShortVersion(assembly, length));
        }

        /// <summary>
        /// Get the full <see cref="Version"/> of the <see cref="Assembly"/>
        /// </summary>
        /// <param name="assembly">The <see cref="Assembly"/> which version we are interested in</param>
        /// <returns>Full <see cref="Version"/> of <see cref="Assembly"/></returns>
        public static Version GetLongVersion(Assembly assembly)
        {
            return assembly == null ?
                null :
                assembly.GetName().Version;
        }

        /// <summary>
        /// Get the short <see cref="Assembly"/> version in a <see cref="string"/> format
        /// </summary>
        /// <param name="assembly">
        /// The <see cref="Assembly"/> which version we are interested in
        /// </param>
        /// <param name="length">The length of the version string</param>
        /// <returns>Short version of <see cref="Assembly"/> in a string format</returns>
        public static string GetShortVersion(Assembly assembly, int length = 2)
        {
            // Return emtpy string if the assembly is null
            if (assembly == null) return string.Empty;

            var version = GetLongVersion(assembly).ToString();
            var sv = version.Split(new char[] { '.' });

            var len = Math.Min(sv.Length, length);
            return string.Join(".", sv, 0, len);
        }
    }
}
