﻿//***************************************************************************
// Contributed by Ondrej Dvorak, 2013: Changes with respect to the DSLPed 
// project
//
// Copyright © 2010 Microsoft Corporation.  All Rights Reserved.
// This code released under the terms of the 
// Microsoft Public License (MS-PL, http://opensource.org/licenses/ms-pl.html.)
//***************************************************************************
using System.Runtime.InteropServices;
using Microsoft.VisualStudio.Shell.Interop;
using Microsoft.VisualStudio.Shell;

namespace Dsl.Ped.Designer
{
    /// <summary>
    /// This is the class that implements the package exposed by this assembly.
    ///
    /// The minimum requirement for a class to be considered a valid package for Visual Studio
    /// is to implement the IVsPackage interface and register itself with the shell.
    /// This package uses the helper classes defined inside the Managed Package Framework (MPF)
    /// to do it: it derives from the Package class that provides the implementation of the 
    /// IVsPackage interface and uses the registration attributes defined in the framework to 
    /// register itself and its components with the shell.
    /// </summary>
    // This attribute tells the PkgDef creation utility (CreatePkgDef.exe) that this class is
    // a package.
    [PackageRegistration(UseManagedResourcesOnly = true)]

    // Register the class as a Designer View in cooperation with the Xml DslPedEditor
    [ProvideXmlEditorChooserDesignerView("DSLPed", DSLPedEditorFactory.Extension, LogicalViewID.Designer, 0x60,
        DesignerLogicalViewEditor = typeof(DSLPedEditorFactory),
        Namespace = "http://schemas.microsoft.com/developer/dslpeddesigner/2010",
        MatchExtensionAndNamespace = false)]
    // And which type of files we want to handle
    [ProvideEditorExtension(typeof(DSLPedEditorFactory), DSLPedEditorFactory.Extension, 0x40, NameResourceID = 106)]
    [ProvideEditorExtension(typeof(DSLPedEditorFactory), ".proj", 0x40, NameResourceID = 106)]
    // We register that our editor supports LOGVIEWID_Designer logical view
    [ProvideEditorLogicalView(typeof(DSLPedEditorFactory), LogicalViewID.Designer)]

    // We register the XML DslPedEditor ("{FA3CD31E-987B-443A-9B81-186104E8DAC1}") as an EditorFactoryNotify
    // object to handle our ".dsl" file extension for the following projects:
    // Microsoft Visual Basic Project
    [EditorFactoryNotifyForProject("{F184B08F-C81C-45F6-A57F-5ABD9991F28F}", DSLPedEditorFactory.Extension, Guids.guidXmlChooserEditorFactory)]
    // Microsoft Visual C# Project
    [EditorFactoryNotifyForProject("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}", DSLPedEditorFactory.Extension, Guids.guidXmlChooserEditorFactory)]

    [EditorFactoryNotifyForProject("{F184B08F-C81C-45F6-A57F-5ABD9991F28F}", ".proj", Guids.guidXmlChooserEditorFactory)]
    // Microsoft Visual C# Project
    [EditorFactoryNotifyForProject("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}", ".proj", Guids.guidXmlChooserEditorFactory)]

    // This attribute is used to register the informations needed to show the this package
    // in the Help/About dialog of Visual Studio.
    [InstalledProductRegistration("#110", "#112", "1.0", IconResourceID = 400)]
    // This attribute is needed to let the shell know that this package exposes some menus.
    [ProvideMenuResource("Menus.ctmenu", 1)]
    // Register the designer of a specific Guid
    [Guid(Guids.guidDslPedDesignerPkgString)]
    // Loads the referenced assemblies
    [ProvideBindingPath]
    public sealed class DslPedDesignerPackage : Package
    {
        /// <summary>
        /// Default constructor of the package.
        /// Inside this method you can place any initialization code that does not require 
        /// any Visual Studio service because at this point the package object is created but 
        /// not sited yet inside Visual Studio environment. The place to do all the other 
        /// initialization is the Initialize method.
        /// </summary>
        public DslPedDesignerPackage()
        {
            
        }

        /////////////////////////////////////////////////////////////////////////////
        // Overriden Package Implementation
        #region Package Members

        /// <summary>
        /// Initialization of the package; this method is called right after the package is sited, so this is the place
        /// where you can put all the initilaization code that rely on services provided by VisualStudio.
        /// </summary>
        protected override void Initialize()
        {
            base.Initialize();

            base.RegisterEditorFactory(new DSLPedEditorFactory(this));

        }
        #endregion

    }
}
