﻿using System;
using System.Windows;
using Dsl.Ped.Framework.Common;

namespace Dsl.Ped.Framework.Projections.ObjectProjections
{
    /// <summary>
    /// Hint for the creation of object-based projections
    /// </summary>
    /// <typeparam name="T">Type of the projection (like TextBox, Label, etc.)</typeparam>
    public class ObjectProjectionHint<T> : ProjectionHint<T>, IObjectProjectionHint<T>
        where T : FrameworkElement, new()
    {
        #region Members

        /// <summary>
        /// Gets the type of the projection
        /// </summary>
        public Type ProjectionType 
        { 
            get { return typeof(T); } 
        }

        #endregion

        /// <summary>
        /// Initializes a new instance of the <see cref="ObjectProjectionHint{T}"/> class.
        /// </summary>
        /// <param name="defaultConfiguration">The default configuration applied to the instance of the projection</param>
        /// <param name="customConfiguration">The custom configuration applied after the <see cref="defaultConfiguration"/></param>
        public ObjectProjectionHint(Action<T, Type> defaultConfiguration, Action<T> customConfiguration)
            : base(defaultConfiguration, customConfiguration)
        {
        }
    }
}
