﻿using System;
using System.Windows;
using Dsl.Ped.Framework.Common;

namespace Dsl.Ped.Framework.Projections.ValueProjections
{
    /// <summary>
    /// Hint for the creation of value-based projections
    /// </summary>
    /// <typeparam name="T"></typeparam>
    public class ValueProjectionHint<T> : ProjectionHint<T>, IValueProjectionHint<T>
        where T : FrameworkElement, new()
    {
        #region Members

        /// <summary>
        /// Gets the type of the projection
        /// </summary>
        public Type ProjectionType 
        { 
            get { return typeof(T); } 
        }

        /// <summary>
        /// Gets the <see cref="DependencyProperty"/> to which the value is bound
        /// </summary>
        public DependencyProperty ValueProperty { get; private set; }

        #endregion

        /// <summary>
        /// Initializes a new instance of the <see cref="ValueProjectionHint{T}"/> class.
        /// </summary>
        /// <param name="valueProperty">The <see cref="DependencyProperty"/> to which the value is bound</param>
        /// <param name="defaultConfiguration">The default configuration applied to the projection </param>
        /// <param name="customConfiguration">The custom configuration applied after <see cref="defaultConfiguration"/></param>
        public ValueProjectionHint(DependencyProperty valueProperty, Action<T, Type> defaultConfiguration, Action<T> customConfiguration)
            : base(defaultConfiguration, customConfiguration)
        {
            this.ValueProperty = valueProperty;
        }
    }
}
